@@ -50,9 +50,11 @@ my $center_x      = $XX / 2;
 my $center_y      = $YY / 2;
 my $factor        = 5;
 my $images_path   = (-e 'images/GFB.png') ? 'images' : 'examples/images';
+my $rpi           = ($F->{'fscreeninfo'}->{'id'} =~ /BCM270(8|9)/i) ? 1 : 0;
 
 $F->cls('OFF');
 
+# if (0) {
 color_mapping();
 plotting();
 lines();
@@ -797,6 +799,16 @@ sub rotate {
                 'file'   => "$images_path/RWBY_Oh_No.jpg"
             }
         );
+    } elsif ($rpi) {
+        $image = $F->load_image(
+            {
+                'x'      => 0,
+                'y'      => 0,
+                'width'  => 160,
+                'height' => 120,
+                'file'   => "$images_path/RWBY_Oh_No.jpg"
+            }
+        );
     } else {
         $image = $F->load_image(
             {
@@ -860,15 +872,26 @@ sub rotate {
 sub flipping {
     print_it($F, 'Loading "RWBY_Faces.png" For Image Flip Tests','FFFF00FF');
 
-    my $image = $F->load_image(
-        {
-            'x'      => 0,
-            'y'      => $F->{'Y_CLIP'},
-            'width'  => $XX,
-            'height' => ($YY - $F->{'Y_CLIP'}),
-            'file'   => "$images_path/RWBY_Faces.png"
-        }
-    );
+    my $image;
+    if ($rpi && $XX > 320) {
+        $image = $F->load_image(
+            {
+                'x'    => 0,
+                'y'    => $F->{'Y_CLIP'},
+                'file' => "$images_path/RWBY_Faces.png"
+            }
+        );
+    } else {
+        $image = $F->load_image(
+            {
+                'x'      => 0,
+                'y'      => $F->{'Y_CLIP'},
+                'width'  => $XX,
+                'height' => ($YY - $F->{'Y_CLIP'}),
+                'file'   => "$images_path/RWBY_Faces.png"
+            }
+        );
+    }
     my $s = time + $factor;
     while (time < $s) {
         foreach my $dir (qw(normal horizontal vertical both)) {
@@ -892,15 +915,27 @@ sub monochrome {
     my $image = shift;
     print_it($F, 'Testing Monochrome Image blitting');
 
-    $image = $F->blit_transform(
-        {
-            'scale' => {
+    if ($F->{'BITS'} == 16) {
+        $image = $F->load_image(
+            {
+                'x'      => 0,
+                'y'      => $F->{'Y_CLIP'},
                 'width'  => int($XX * .6),
-                'height' => int($YY * .6)
-            },
-            'blit_data' => $image
-        }
-    );
+                'height' => int($YY * .6),
+                'file'   => "$images_path/RWBY_Faces.png"
+            }
+        );
+    } else {
+        $image = $F->blit_transform(
+            {
+                'scale' => {
+                    'width'  => int($XX * .6),
+                    'height' => int($YY * .6)
+                },
+                'blit_data' => $image
+            }
+        );
+    }
     $image->{'image'} = $F->monochrome({'image' => $image->{'image'}, 'bits' => $F->{'BITS'}});
     my $s = time + $factor;
     while (time < $s) {
@@ -974,7 +1009,7 @@ sub animated {
                     }
                 }
             }
-            last if ($XX <= 320);
+            last if ($XX <= 320 || $rpi);
         }
     }
 }
@@ -1134,7 +1169,7 @@ sub unmask_drawing {
 sub print_it {
     my $fb      = shift;
     my $message = shift;
-    my $color   = shift || '00FF00FF';
+    my $color   = shift || 'FFFF00FF';
 
     $fb->normal_mode();
     $fb->clip_reset();
