@@ -316,32 +316,22 @@ Demonstrates how to use threads with "Graphics::Framebuffer"
 
 =head1 SYNOPSIS
 
-perl threadstest.pl [mali] [file] [# of threads]
+ perl threadstest.pl [file] [# of threads]
 
 =head1 OPTIONS
 
 The options can be passed in any order and all are optional.
 
-=over 1
-=item B< mali >
+=over 2
 
-Causes the Graphics::Framebuffer module to correct for driver errors
-with some MALI GPUs in ARM chipsets.  While it is mainly designed to
-override some of the calculations for Mali chipsets, it may work with
-others.  Only use if you are either getting errors, or weirdness in
-drawing.
-
-Contact the Graphics::Framebuffer author if you are having troubles
-getting it to work.
-
-=item B< file >
+=item B<file>
 
 Changes the internal logic of Graphics::Framebuffer to instead draw
 using a file handle, instead of using a Mmapped variable.
 
 Only use if you are having stability issues, as it is slower.
 
-=item B< # of threads >
+=item B<number of threads >
 
 This is an integer (yes, just a number) indicating how many threads
 to spawn to draw.
@@ -350,4 +340,5 @@ Typically this is done automatically with the number of cores the
 script detects, but this overrides the detection.
 
 =back
+
 =cut
